<template>
    <div >
        <v-card class="mb-3">
            <v-container>
                <v-row>
                    <v-col xs="12" sm="6" md="6">
                        <v-text-field
                            prepend-icon="search"
                            :label="trans('messages.filter_by_name')"
                            v-model="filters.name"
                            @keyup="searchRole"
                            dense
                        ></v-text-field>
                    </v-col>
                    <v-col xs="12" sm="6" md="6" class="text-right">
                        <v-btn
                            @click="$router.push({ name: 'roles.create' })"
                            class="primary lighten-1"
                            dark
                        >
                            {{ trans('messages.new_role') }}
                            <v-icon right>add</v-icon>
                        </v-btn>
                    </v-col>
                </v-row>
            </v-container>
        </v-card>
        <v-card>
            <v-card-title>
                    <div class="headline">
                        {{ trans('messages.all_roles') }}
                    </div>
            </v-card-title>
            <v-divider></v-divider>
            <v-data-table
                v-bind:headers="headers"
                v-bind:options.sync="pagination"
                :items="items"
                :server-items-length="total_items"
                class="elevation-3"
            >
                <template v-slot:item="{ item }">
                    <tr>
                        <td class="text-center">
                            <v-menu>
                                <template v-slot:activator="{ on }">
                                    <v-btn icon v-on="on">
                                        <v-icon>more_vert</v-icon>
                                    </v-btn>
                                </template>
                                <v-list>
                                    <v-list-item
                                        @click="
                                            $router.push({
                                                name: 'roles.edit',
                                                params: { id: item.id },
                                            })
                                        "
                                    >
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> edit </v-icon>
                                            {{ trans('messages.edit') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                    <v-list-item @click="deleteRole(item)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> delete_forever </v-icon>
                                            {{ trans('messages.delete') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                </v-list>
                            </v-menu>
                        </td>
                        <td class="text-center">{{ item.name }}</td>
                        <td class="text-center">{{ item.created_at | formatDate }}</td>
                    </tr>
                </template>
            </v-data-table>
        </v-card>
    </div>
</template>
<script>
export default {
    data() {
        const self = this;
        return {
            total_items: 0,
            loading: false,
            pagination: {},
            items: [],
            headers: [
                {
                    text: self.trans('messages.action'),
                    value: false,
                    align: 'center',
                    sortable: false,
                },
                { text: self.trans('messages.name'), value: 'name', align: 'center', sortable: true },
                {
                    text: self.trans('messages.created_at'),
                    value: 'created_at',
                    align: 'center',
                    sortable: true,
                },
            ],
            filters: {
                name: '',
            },
        };
    },
    watch: {
        pagination: {
            handler() {
                const self = this;
                self.getRolesFromApi();
            },
        },
    },
    methods: {
        getRolesFromApi() {
            const self = this;

            self.loading = true;

            const { sortBy, sortDesc, page, itemsPerPage } = self.pagination;

            axios
                .get('/admin/roles', {
                    params: {
                        sort_by: sortBy,
                        descending: sortDesc,
                        page: page,
                        rowsPerPage: itemsPerPage,
                        name: self.filters.name,
                    },
                })
                .then(function(response) {
                    self.total_items = response.data.total;
                    self.items = response.data.data;
                    self.loading = false;
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        searchRole() {
            const self = this;
            self.getRolesFromApi();
        },
        deleteRole(item) {
            const self = this;
            self.$store.commit('showDialog', {
                type: 'confirm',
                icon: 'warning',
                title: self.trans('messages.are_you_sure'),
                message: self.trans('messages.you_cant_restore_it'),
                okCb: () => {
                    axios
                        .delete('/admin/roles/' + item.id)
                        .then(function(response) {
                            self.$store.commit('showSnackbar', {
                                message: response.data.msg,
                                color: response.data.success,
                            });

                            if (response.data.success === true) {
                                self.getRolesFromApi();
                            }
                        })
                        .catch(function(error) {
                            console.log(error);
                        });
                },
                cancelCb: () => {
                    console.log('CANCEL');
                },
            });
        },
    },
};
</script>
